Contributing to Betty - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Contributing to Betty

Betty is Free and Open Source Software, designed and maintained by volunteers. As such you are welcome to report bugs or submit improvements.

Examples of contributions:

- translations

- UX and graphic design

- coding in Python, JavaScript, HTML, CSS, and more

Important

Read Code of Conduct before sharing your contributions